powered by
Retrieves an assessment
rl_assessment_id(assessment_id = 1425064)
A tibble where each column represents a unique API response JSON key for the supplied assessment_id. The columns include key information about the Red List assessment, such as taxon details, category, year, and other relevant metadata.
assessment_id
Assessment ID
if (FALSE) { rl_assessment_id(1425064) }
Run the code above in your browser using DataLab