A tibble (class tbl_df, tbl, data.frame) where each column represents a unique API response JSON key.
If code = NULL, the tibble contains available habitat codes and their descriptions.
If code is provided, the tibble contains assessment data for the specified habitat(s), including taxon details,
description, red list category, year, assessment id, and other relevant metadata.